# oxbow <a href="https://github.com/abdenlab/oxbow"><img align="right" src="./docs/_static/logo.svg" height="38"></img></a>
[![DOI](https://zenodo.org/badge/641466193.svg)](https://zenodo.org/doi/10.5281/zenodo.10573864)
[![Docs](https://readthedocs.org/projects/cooler/badge/?version=latest)](https://app.readthedocs.org/projects/oxbow/)

Oxbow makes genomic data accessible for high-performance analytics.

Oxbow is a data unification layer that leverages the widely-adopted Apache 
Arrow in-memory format to improve accessibility and interoperability of 
tabular genomic data with the modern data ecosystem. Read specialized 
genomic file formats as in-memory or larger-than-memory data frames in 
Python, R, and more. Data I/O is handled in Rust. Learn more from our 
[blog post](https://open.substack.com/pub/lifeinbytes/p/breaking-out-of-bioinformatic-data-silos?r=jue12&utm_campaign=post&utm_medium=web).

Read the latest [documentation](https://oxbow.readthedocs.io/).

## Contributing

Want to contribute? See the [contributing guide](https://oxbow.readthedocs.io/en/latest/contributing-guide/).
